@@ -16,16 +16,21 @@
 //! Real-time and static test `Clock` implementations.
 
 use std::{
-    collections::{BTreeMap, HashMap},
+    collections::{BTreeMap, BinaryHeap, HashMap},
     ops::Deref,
+    pin::Pin,
+    sync::Arc,
+    task::{Context, Poll},
 };
 
 use chrono::{DateTime, Utc};
+use futures::Stream;
 use nautilus_core::{
     correctness::{check_positive_u64, check_predicate_true, check_valid_string, FAILED},
     nanos::UnixNanos,
     time::{get_atomic_clock_realtime, AtomicTime},
 };
+use tokio::sync::Mutex;
 use ustr::Ustr;
 
 use crate::timer::{LiveTimer, TestTimer, TimeEvent, TimeEventCallback, TimeEventHandlerV2};
@@ -33,6 +38,7 @@ use crate::timer::{LiveTimer, TestTimer, TimeEvent, TimeEventCallback, TimeEvent
 /// Represents a type of clock.
 ///
 /// # Notes
+///
 /// An active timer is one which has not expired (`timer.is_expired == False`).
 pub trait Clock {
     /// Returns the current date and time as a timezone-aware `DateTime<UTC>`.
@@ -62,6 +68,11 @@ pub trait Clock {
     /// does not have an event handler, then this handler is used.
     fn register_default_handler(&mut self, callback: TimeEventCallback);
 
+    /// Get handler for [`TimeEvent`]
+    ///
+    /// Note: Panics if the event does not have an associated handler
+    fn get_handler(&self, event: TimeEvent) -> TimeEventHandlerV2;
+
     /// Set a `Timer` to alert at a particular time. Optional
     /// callback gets used to handle generated events.
     fn set_time_alert_ns(
@@ -83,6 +94,9 @@ pub trait Clock {
         callback: Option<TimeEventCallback>,
     );
 
+    /// Returns the time interval in which the timer `name` is triggered.
+    ///
+    /// If the timer doesn't exist 0 is returned.
     fn next_time_ns(&self, name: &str) -> UnixNanos;
     fn cancel_timer(&mut self, name: &str);
     fn cancel_timers(&mut self);
@@ -98,6 +112,7 @@ pub struct TestClock {
     timers: BTreeMap<Ustr, TestTimer>,
     default_callback: Option<TimeEventCallback>,
     callbacks: HashMap<Ustr, TimeEventCallback>,
+    heap: BinaryHeap<TimeEvent>,
 }
 
 impl TestClock {
@@ -109,6 +124,7 @@ impl TestClock {
             timers: BTreeMap::new(),
             default_callback: None,
             callbacks: HashMap::new(),
+            heap: BinaryHeap::new(),
         }
     }
 
@@ -139,15 +155,40 @@ impl TestClock {
             self.time.set_time(to_time_ns);
         }
 
-        let mut timers: Vec<TimeEvent> = self
+        let mut events: Vec<TimeEvent> = self
             .timers
             .iter_mut()
             .filter(|(_, timer)| !timer.is_expired())
             .flat_map(|(_, timer)| timer.advance(to_time_ns))
             .collect();
 
-        timers.sort_by(|a, b| a.ts_event.cmp(&b.ts_event));
-        timers
+        events.sort_by(|a, b| a.ts_event.cmp(&b.ts_event));
+        events
+    }
+
+    /// Advances the internal clock to the specified `to_time_ns` and optionally sets the clock to that time.
+    ///
+    /// Pushes the [`TimeEvent`]s on the heap to ensure ordering
+    ///
+    /// Note: `set_time` is not used but present to keep backward compatible api call
+    pub fn advance_to_time_on_heap(&mut self, to_time_ns: UnixNanos) {
+        // Time should be non-decreasing
+        assert!(
+            to_time_ns >= self.time.get_time_ns(),
+            "`to_time_ns` {} was < `self.time.get_time_ns()` {}",
+            to_time_ns,
+            self.time.get_time_ns()
+        );
+
+        self.time.set_time(to_time_ns);
+
+        self.timers
+            .iter_mut()
+            .filter(|(_, timer)| !timer.is_expired())
+            .flat_map(|(_, timer)| timer.advance(to_time_ns))
+            .for_each(|event| {
+                self.heap.push(event);
+            });
     }
 
     /// Matches `TimeEvent` objects with their corresponding event handlers.
@@ -173,6 +214,14 @@ impl TestClock {
     }
 }
 
+impl Iterator for TestClock {
+    type Item = TimeEventHandlerV2;
+
+    fn next(&mut self) -> Option<Self::Item> {
+        self.heap.pop().map(|event| self.get_handler(event))
+    }
+}
+
 impl Default for TestClock {
     /// Creates a new default [`TestClock`] instance.
     fn default() -> Self {
@@ -224,6 +273,18 @@ impl Clock for TestClock {
         self.default_callback = Some(callback);
     }
 
+    fn get_handler(&self, event: TimeEvent) -> TimeEventHandlerV2 {
+        // Get the callback from either the event-specific callbacks or default callback
+        let callback = self
+            .callbacks
+            .get(&event.name)
+            .cloned()
+            .or_else(|| self.default_callback.clone())
+            .unwrap_or_else(|| panic!("Event '{}' should have associated handler", event.name));
+
+        TimeEventHandlerV2::new(event, callback)
+    }
+
     fn set_time_alert_ns(
         &mut self,
         name: &str,
@@ -310,6 +371,9 @@ pub struct LiveClock {
     time: &'static AtomicTime,
     timers: HashMap<Ustr, LiveTimer>,
     default_callback: Option<TimeEventCallback>,
+    pub heap: Arc<Mutex<BinaryHeap<TimeEvent>>>,
+    #[allow(dead_code)]
+    callbacks: HashMap<Ustr, TimeEventCallback>,
 }
 
 impl LiveClock {
@@ -320,9 +384,16 @@ impl LiveClock {
             time: get_atomic_clock_realtime(),
             timers: HashMap::new(),
             default_callback: None,
+            heap: Arc::new(Mutex::new(BinaryHeap::new())),
+            callbacks: HashMap::new(),
         }
     }
 
+    #[must_use]
+    pub fn get_event_stream(&self) -> TimeEventStream {
+        TimeEventStream::new(self.heap.clone())
+    }
+
     #[must_use]
     pub const fn get_timers(&self) -> &HashMap<Ustr, LiveTimer> {
         &self.timers
@@ -380,6 +451,25 @@ impl Clock for LiveClock {
         self.default_callback = Some(handler);
     }
 
+    #[allow(unused_variables)]
+    fn get_handler(&self, event: TimeEvent) -> TimeEventHandlerV2 {
+        #[cfg(not(feature = "clock_v2"))]
+        panic!("Cannot get live clock handler without 'clock_v2' feature");
+
+        // Get the callback from either the event-specific callbacks or default callback
+        #[cfg(feature = "clock_v2")]
+        {
+            let callback = self
+                .callbacks
+                .get(&event.name)
+                .cloned()
+                .or_else(|| self.default_callback.clone())
+                .unwrap_or_else(|| panic!("Event '{}' should have associated handler", event.name));
+
+            TimeEventHandlerV2::new(event, callback)
+        }
+    }
+
     fn set_time_alert_ns(
         &mut self,
         name: &str,
@@ -397,10 +487,27 @@ impl Clock for LiveClock {
             None => self.default_callback.clone().unwrap(),
         };
 
+        #[cfg(feature = "clock_v2")]
+        {
+            let name = Ustr::from(name);
+            self.callbacks.insert(name, callback.clone());
+        }
+
         let ts_now = self.get_time_ns();
         alert_time_ns = std::cmp::max(alert_time_ns, ts_now);
         let interval_ns = (alert_time_ns - ts_now).into();
+
+        #[cfg(not(feature = "clock_v2"))]
         let mut timer = LiveTimer::new(name, interval_ns, ts_now, Some(alert_time_ns), callback);
+        #[cfg(feature = "clock_v2")]
+        let mut timer = LiveTimer::new(
+            name,
+            interval_ns,
+            ts_now,
+            Some(alert_time_ns),
+            callback,
+            self.heap.clone(),
+        );
 
         timer.start();
         self.timers.insert(Ustr::from(name), timer);
@@ -427,7 +534,23 @@ impl Clock for LiveClock {
             None => self.default_callback.clone().unwrap(),
         };
 
+        #[cfg(feature = "clock_v2")]
+        {
+            let name = Ustr::from(name);
+            self.callbacks.insert(name, callback.clone());
+        }
+
+        #[cfg(not(feature = "clock_v2"))]
         let mut timer = LiveTimer::new(name, interval_ns, start_time_ns, stop_time_ns, callback);
+        #[cfg(feature = "clock_v2")]
+        let mut timer = LiveTimer::new(
+            name,
+            interval_ns,
+            start_time_ns,
+            stop_time_ns,
+            callback,
+            self.heap.clone(),
+        );
         timer.start();
         self.timers.insert(Ustr::from(name), timer);
     }
@@ -445,23 +568,52 @@ impl Clock for LiveClock {
         match timer {
             None => {}
             Some(mut timer) => {
-                if let Err(e) = timer.cancel() {
-                    log::error!("Error on timer cancel: {:?}", e);
-                }
+                timer.cancel();
             }
         }
     }
 
     fn cancel_timers(&mut self) {
         for timer in &mut self.timers.values_mut() {
-            if let Err(e) = timer.cancel() {
-                log::error!("Error on timer cancel: {:?}", e);
-            }
+            timer.cancel();
         }
         self.timers.clear();
     }
 }
 
+// Helper struct to stream events from the heap
+pub struct TimeEventStream {
+    heap: Arc<Mutex<BinaryHeap<TimeEvent>>>,
+}
+
+impl TimeEventStream {
+    pub const fn new(heap: Arc<Mutex<BinaryHeap<TimeEvent>>>) -> Self {
+        Self { heap }
+    }
+}
+
+impl Stream for TimeEventStream {
+    type Item = TimeEvent;
+
+    fn poll_next(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Option<Self::Item>> {
+        let mut heap = match self.heap.try_lock() {
+            Ok(guard) => guard,
+            Err(e) => {
+                tracing::error!("Unable to get LiveClock heap lock: {e}");
+                cx.waker().wake_by_ref();
+                return Poll::Pending;
+            }
+        };
+
+        if let Some(event) = heap.pop() {
+            Poll::Ready(Some(event))
+        } else {
+            cx.waker().wake_by_ref();
+            Poll::Pending
+        }
+    }
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // Tests
 ////////////////////////////////////////////////////////////////////////////////
@@ -472,22 +624,23 @@ mod tests {
     use rstest::{fixture, rstest};
 
     use super::*;
-    use crate::timer::RustTimeEventCallback;
 
     #[derive(Default)]
     struct TestCallback {
         called: Rc<RefCell<bool>>,
     }
 
-    impl RustTimeEventCallback for TestCallback {
-        fn call(&self, _event: TimeEvent) {
-            *self.called.borrow_mut() = true;
+    impl TestCallback {
+        const fn new(called: Rc<RefCell<bool>>) -> Self {
+            Self { called }
         }
     }
 
     impl From<TestCallback> for TimeEventCallback {
-        fn from(val: TestCallback) -> Self {
-            Self::Rust(Rc::new(val))
+        fn from(callback: TestCallback) -> Self {
+            Self::Rust(Rc::new(move |_event: TimeEvent| {
+                *callback.called.borrow_mut() = true;
+            }))
         }
     }
 
@@ -553,13 +706,8 @@ mod tests {
         let default_called = Rc::new(RefCell::new(false));
         let custom_called = Rc::new(RefCell::new(false));
 
-        let default_callback: Rc<dyn RustTimeEventCallback> = Rc::new(TestCallback {
-            called: Rc::clone(&default_called),
-        });
-
-        let custom_callback: Rc<dyn RustTimeEventCallback> = Rc::new(TestCallback {
-            called: Rc::clone(&custom_called),
-        });
+        let default_callback = TestCallback::new(Rc::clone(&default_called));
+        let custom_callback = TestCallback::new(Rc::clone(&custom_called));
 
         clock.register_default_handler(TimeEventCallback::from(default_callback));
         clock.set_time_alert_ns("default_timer", (*clock.timestamp_ns() + 1000).into(), None);
