@@ -15,13 +15,21 @@
 
 //! Real-time and test timers for use with `Clock` implementations.
 
+#[rustfmt::skip]
+#[cfg(feature = "clock_v2")]
+use std::collections::BinaryHeap;
+
+#[rustfmt::skip]
+#[cfg(feature = "clock_v2")]
+use tokio::sync::Mutex;
+
 use std::{
     cmp::Ordering,
-    fmt::Display,
+    fmt::{Debug, Display},
     num::NonZeroU64,
     rc::Rc,
     sync::{
-        atomic::{self, AtomicBool, AtomicU64},
+        atomic::{self, AtomicU64},
         Arc,
     },
 };
@@ -36,7 +44,7 @@ use nautilus_core::{
 #[cfg(feature = "python")]
 use pyo3::{PyObject, Python};
 use tokio::{
-    sync::oneshot,
+    task::JoinHandle,
     time::{Duration, Instant},
 };
 use ustr::Ustr;
@@ -53,6 +61,7 @@ use crate::runtime::get_runtime;
 ///
 /// A `TimeEvent` carries metadata such as the event's name, a unique event ID,
 /// and timestamps indicating when the event was scheduled to occur and when it was initialized.
+#[derive(Eq)]
 pub struct TimeEvent {
     /// The event name, identifying the nature or purpose of the event.
     pub name: Ustr,
@@ -64,6 +73,20 @@ pub struct TimeEvent {
     pub ts_init: UnixNanos,
 }
 
+/// Reverse order for `TimeEvent` comparison to be used in max heap.
+impl PartialOrd for TimeEvent {
+    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
+        Some(self.cmp(other))
+    }
+}
+
+/// Reverse order for `TimeEvent` comparison to be used in max heap.
+impl Ord for TimeEvent {
+    fn cmp(&self, other: &Self) -> Ordering {
+        other.ts_event.cmp(&self.ts_event)
+    }
+}
+
 impl TimeEvent {
     /// Creates a new [`TimeEvent`] instance.
     ///
@@ -97,15 +120,23 @@ impl PartialEq for TimeEvent {
     }
 }
 
-pub trait RustTimeEventCallback {
-    fn call(&self, event: TimeEvent);
-}
+pub type RustTimeEventCallback = dyn Fn(TimeEvent);
 
 #[derive(Clone)]
 pub enum TimeEventCallback {
     #[cfg(feature = "python")]
-    Python(PyObject),
-    Rust(Rc<dyn RustTimeEventCallback>),
+    Python(Arc<PyObject>),
+    Rust(Rc<RustTimeEventCallback>),
+}
+
+impl Debug for TimeEventCallback {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match self {
+            #[cfg(feature = "python")]
+            Self::Python(_) => f.write_str("Python callback"),
+            Self::Rust(_) => f.write_str("Rust callback"),
+        }
+    }
 }
 
 impl TimeEventCallback {
@@ -117,13 +148,13 @@ impl TimeEventCallback {
                     callback.call1(py, (event,)).unwrap();
                 });
             }
-            Self::Rust(callback) => callback.call(event),
+            Self::Rust(callback) => callback(event),
         }
     }
 }
 
-impl From<Rc<dyn RustTimeEventCallback>> for TimeEventCallback {
-    fn from(value: Rc<dyn RustTimeEventCallback>) -> Self {
+impl From<Rc<RustTimeEventCallback>> for TimeEventCallback {
+    fn from(value: Rc<RustTimeEventCallback>) -> Self {
         Self::Rust(value)
     }
 }
@@ -131,7 +162,7 @@ impl From<Rc<dyn RustTimeEventCallback>> for TimeEventCallback {
 #[cfg(feature = "python")]
 impl From<PyObject> for TimeEventCallback {
     fn from(value: PyObject) -> Self {
-        Self::Python(value)
+        Self::Python(Arc::new(value))
     }
 }
 
@@ -140,7 +171,7 @@ unsafe impl Send for TimeEventCallback {}
 unsafe impl Sync for TimeEventCallback {}
 
 #[repr(C)]
-#[derive(Clone)]
+#[derive(Clone, Debug)]
 /// Represents a time event and its associated handler.
 ///
 /// `TimeEventHandler` associates a `TimeEvent` with a callback function that is triggered
@@ -158,6 +189,11 @@ impl TimeEventHandlerV2 {
     pub const fn new(event: TimeEvent, callback: TimeEventCallback) -> Self {
         Self { event, callback }
     }
+
+    pub fn run(self) {
+        let Self { event, callback } = self;
+        callback.call(event);
+    }
 }
 
 impl PartialOrd for TimeEventHandlerV2 {
@@ -313,9 +349,10 @@ pub struct LiveTimer {
     /// The optional stop time of the timer in UNIX nanoseconds.
     pub stop_time_ns: Option<UnixNanos>,
     next_time_ns: Arc<AtomicU64>,
-    is_expired: Arc<AtomicBool>,
     callback: TimeEventCallback,
-    canceler: Option<oneshot::Sender<()>>,
+    task_handle: Option<JoinHandle<()>>,
+    #[cfg(feature = "clock_v2")]
+    heap: Arc<Mutex<BinaryHeap<TimeEvent>>>,
 }
 
 impl LiveTimer {
@@ -327,6 +364,7 @@ impl LiveTimer {
     /// - If `name` is not a valid string.
     /// - If `interval_ns` is zero.
     #[must_use]
+    #[cfg(not(feature = "clock_v2"))]
     pub fn new(
         name: &str,
         interval_ns: u64,
@@ -335,19 +373,52 @@ impl LiveTimer {
         callback: TimeEventCallback,
     ) -> Self {
         check_valid_string(name, stringify!(name)).expect(FAILED);
-        // SAFETY: Guaranteed to be non-zero
-        let interval_ns = NonZeroU64::new(std::cmp::max(interval_ns, 1)).unwrap();
+        let interval_ns =
+            NonZeroU64::new(std::cmp::max(interval_ns, 1)).expect("`interval_ns` must be non-zero");
 
-        log::debug!("Creating timer '{}'", name);
+        log::debug!("Creating timer '{name}'");
         Self {
             name: Ustr::from(name),
             interval_ns,
             start_time_ns,
             stop_time_ns,
             next_time_ns: Arc::new(AtomicU64::new(start_time_ns.as_u64() + interval_ns.get())),
-            is_expired: Arc::new(AtomicBool::new(false)),
             callback,
-            canceler: None,
+            task_handle: None,
+        }
+    }
+
+    /// Creates a new [`LiveTimer`] instance.
+    ///
+    /// # Panics
+    ///
+    /// This function panics:
+    /// - If `name` is not a valid string.
+    /// - If `interval_ns` is zero.
+    #[must_use]
+    #[cfg(feature = "clock_v2")]
+    pub fn new(
+        name: &str,
+        interval_ns: u64,
+        start_time_ns: UnixNanos,
+        stop_time_ns: Option<UnixNanos>,
+        callback: TimeEventCallback,
+        heap: Arc<Mutex<BinaryHeap<TimeEvent>>>,
+    ) -> Self {
+        check_valid_string(name, stringify!(name)).expect(FAILED);
+        // SAFETY: Guaranteed to be non-zero
+        let interval_ns = NonZeroU64::new(std::cmp::max(interval_ns, 1)).unwrap();
+
+        log::debug!("Creating timer '{name}'");
+        Self {
+            name: Ustr::from(name),
+            interval_ns,
+            start_time_ns,
+            stop_time_ns,
+            next_time_ns: Arc::new(AtomicU64::new(start_time_ns.as_u64() + interval_ns.get())),
+            callback,
+            heap,
+            task_handle: None,
         }
     }
 
@@ -362,9 +433,12 @@ impl LiveTimer {
     /// Returns whether the timer is expired.
     ///
     /// An expired timer will not trigger any further events.
+    /// A timer that has not been started is not expired.
     #[must_use]
     pub fn is_expired(&self) -> bool {
-        self.is_expired.load(atomic::Ordering::SeqCst)
+        self.task_handle
+            .as_ref()
+            .is_some_and(tokio::task::JoinHandle::is_finished)
     }
 
     /// Starts the timer.
@@ -377,27 +451,17 @@ impl LiveTimer {
         let next_time_ns = self.next_time_ns.load(atomic::Ordering::SeqCst);
         let next_time_atomic = self.next_time_ns.clone();
         let interval_ns = self.interval_ns.get();
-        let is_expired = self.is_expired.clone();
-
-        // TODO: Live timer is currently multi-threaded
-        // and only supports the python event handler
-        #[cfg(feature = "python")]
-        let callback: PyObject = match self.callback.clone() {
-            TimeEventCallback::Python(callback) => callback,
-            TimeEventCallback::Rust(_) => {
-                panic!("Live timer does not support Rust callbacks right now")
-            }
-        };
 
         // Floor the next time to the nearest microsecond which is within the timers accuracy
         let mut next_time_ns = UnixNanos::from(floor_to_nearest_microsecond(next_time_ns));
 
-        // Set up oneshot channel for canceling timer task
-        let (cancel_tx, mut cancel_rx) = oneshot::channel();
-        self.canceler = Some(cancel_tx);
+        #[cfg(feature = "clock_v2")]
+        let heap = self.heap.clone();
 
+        let callback = self.callback.clone();
         let rt = get_runtime();
-        rt.spawn(async move {
+
+        let handle = rt.spawn(async move {
             let clock = get_atomic_clock_realtime();
             let now_ns = clock.get_time_ns();
 
@@ -415,46 +479,50 @@ impl LiveTimer {
             loop {
                 // SAFETY: `timer.tick` is cancellation safe, if the cancel branch completes
                 // first then no tick has been consumed (no event was ready).
-                tokio::select! {
-                    _ = timer.tick() => {
-                        let now_ns = clock.get_time_ns();
-                        #[cfg(feature = "python")]
-                        call_python_with_time_event(event_name, next_time_ns, now_ns, &callback);
+                timer.tick().await;
+                let now_ns = clock.get_time_ns();
 
-                        // Prepare next time interval
-                        next_time_ns += interval_ns;
-                        next_time_atomic.store(next_time_ns.as_u64(), atomic::Ordering::SeqCst);
-
-                        // Check if expired
-                        if let Some(stop_time_ns) = stop_time_ns {
-                            if std::cmp::max(next_time_ns, now_ns) >= stop_time_ns {
-                                break; // Timer expired
-                            }
+                #[cfg(feature = "python")]
+                {
+                    match callback {
+                        TimeEventCallback::Python(ref callback) => {
+                            call_python_with_time_event(event_name, next_time_ns, now_ns, callback);
                         }
-                    },
-                    _ = (&mut cancel_rx) => {
-                        tracing::trace!("Received timer cancel");
-                        break; // Timer canceled
-                    },
+                        // Note: Clock v1 style path should not be called with Rust callback
+                        TimeEventCallback::Rust(_) => {}
+                    };
+                }
+
+                #[cfg(feature = "clock_v2")]
+                {
+                    let event = TimeEvent::new(event_name, UUID4::new(), next_time_ns, now_ns);
+                    heap.lock().await.push(event);
+                }
+
+                // Prepare next time interval
+                next_time_ns += interval_ns;
+                next_time_atomic.store(next_time_ns.as_u64(), atomic::Ordering::SeqCst);
+
+                // Check if expired
+                if let Some(stop_time_ns) = stop_time_ns {
+                    if std::cmp::max(next_time_ns, now_ns) >= stop_time_ns {
+                        break; // Timer expired
+                    }
                 }
             }
-
-            is_expired.store(true, atomic::Ordering::SeqCst);
-
-            Ok::<(), anyhow::Error>(())
         });
+
+        self.task_handle = Some(handle);
     }
 
-    /// Cancels the timer (the timer will not generate a final event).
-    pub fn cancel(&mut self) -> anyhow::Result<()> {
+    /// Cancels the timer.
+    ///
+    /// The timer will not generate a final event.
+    pub fn cancel(&mut self) {
         log::debug!("Cancel timer '{}'", self.name);
-        if !self.is_expired.load(atomic::Ordering::SeqCst) {
-            if let Some(sender) = self.canceler.take() {
-                // Send cancellation signal
-                sender.send(()).map_err(|e| anyhow::anyhow!("{:?}", e))?;
-            }
+        if let Some(ref handle) = self.task_handle {
+            handle.abort();
         }
-        Ok(())
     }
 }
 
@@ -476,7 +544,7 @@ fn call_python_with_time_event(
 
         match callback.call1(py, (capsule,)) {
             Ok(_) => {}
-            Err(e) => tracing::error!("Error on callback: {:?}", e),
+            Err(e) => tracing::error!("Error on callback: {e:?}"),
         };
     });
 }
