@@ -24,12 +24,12 @@ pub mod sql;
 use pyo3::{prelude::*, pymodule};
 
 #[pymodule]
-pub fn infrastructure(_: Python<'_>, m: &PyModule) -> PyResult<()> {
+pub fn infrastructure(_: Python<'_>, m: &Bound<'_, PyModule>) -> PyResult<()> {
     #[cfg(feature = "redis")]
     m.add_class::<crate::redis::cache::RedisCacheDatabase>()?;
     #[cfg(feature = "redis")]
     m.add_class::<crate::redis::msgbus::RedisMessageBusDatabase>()?;
     #[cfg(feature = "postgres")]
-    m.add_class::<crate::sql::cache_database::PostgresCacheDatabase>()?;
+    m.add_class::<crate::sql::cache::PostgresCacheDatabase>()?;
     Ok(())
 }
