@@ -18,11 +18,14 @@ use std::{collections::HashMap, str::FromStr};
 use nautilus_core::{nanos::UnixNanos, uuid::UUID4};
 use nautilus_model::{
     enums::{ContingencyType, LiquiditySide, OrderSide, OrderType, TimeInForce, TriggerType},
-    events::order::{
-        OrderAccepted, OrderCancelRejected, OrderCanceled, OrderDenied, OrderEmulated,
-        OrderEventAny, OrderExpired, OrderFilled, OrderInitialized, OrderModifyRejected,
-        OrderPendingCancel, OrderPendingUpdate, OrderRejected, OrderReleased, OrderSubmitted,
-        OrderTriggered, OrderUpdated,
+    events::{
+        order::{
+            OrderAccepted, OrderCancelRejected, OrderCanceled, OrderDenied, OrderEmulated,
+            OrderEventAny, OrderExpired, OrderFilled, OrderInitialized, OrderModifyRejected,
+            OrderPendingCancel, OrderPendingUpdate, OrderRejected, OrderReleased, OrderSubmitted,
+            OrderTriggered, OrderUpdated,
+        },
+        position::snapshot::PositionSnapshot,
     },
     identifiers::{
         AccountId, ClientOrderId, ExecAlgorithmId, InstrumentId, OrderListId, PositionId,
@@ -52,6 +55,7 @@ pub struct OrderReleasedModel(pub OrderReleased);
 pub struct OrderSubmittedModel(pub OrderSubmitted);
 pub struct OrderTriggeredModel(pub OrderTriggered);
 pub struct OrderUpdatedModel(pub OrderUpdated);
+pub struct PositionSnapshotModel(pub PositionSnapshot);
 
 impl<'r> FromRow<'r, PgRow> for OrderEventAnyModel {
     fn from_row(row: &'r PgRow) -> Result<Self, sqlx::Error> {
@@ -105,10 +109,7 @@ impl<'r> FromRow<'r, PgRow> for OrderEventAnyModel {
             let model = OrderUpdatedModel::from_row(row)?;
             Ok(OrderEventAnyModel(OrderEventAny::Updated(model.0)))
         } else {
-            panic!(
-                "Unknown order event kind: {} in Postgres transformation",
-                kind
-            )
+            panic!("Unknown order event kind: {kind} in Postgres transformation",)
         }
     }
 }
@@ -117,7 +118,7 @@ impl<'r> FromRow<'r, PgRow> for OrderInitializedModel {
     fn from_row(row: &'r PgRow) -> Result<Self, sqlx::Error> {
         let event_id = row.try_get::<&str, _>("id").map(UUID4::from)?;
         let client_order_id = row
-            .try_get::<&str, _>("order_id")
+            .try_get::<&str, _>("client_order_id")
             .map(ClientOrderId::from)?;
         let trader_id = row.try_get::<&str, _>("trader_id").map(TraderId::from)?;
         let strategy_id = row
@@ -140,12 +141,8 @@ impl<'r> FromRow<'r, PgRow> for OrderInitializedModel {
         let reduce_only = row.try_get::<bool, _>("reduce_only")?;
         let quote_quantity = row.try_get::<bool, _>("quote_quantity")?;
         let reconciliation = row.try_get::<bool, _>("reconciliation")?;
-        let ts_event = row
-            .try_get::<String, _>("ts_event")
-            .map(|res| UnixNanos::from(res.as_str()))?;
-        let ts_init = row
-            .try_get::<String, _>("ts_init")
-            .map(|res| UnixNanos::from(res.as_str()))?;
+        let ts_event = row.try_get::<String, _>("ts_event").map(UnixNanos::from)?;
+        let ts_init = row.try_get::<String, _>("ts_init").map(UnixNanos::from)?;
         let price = row
             .try_get::<Option<&str>, _>("price")
             .ok()
@@ -273,8 +270,8 @@ impl<'r> FromRow<'r, PgRow> for OrderAcceptedModel {
         let instrument_id = row
             .try_get::<&str, _>("instrument_id")
             .map(InstrumentId::from)?;
-        let order_id = row
-            .try_get::<&str, _>("order_id")
+        let client_order_id = row
+            .try_get::<&str, _>("client_order_id")
             .map(ClientOrderId::from)?;
         let venue_order_id = row
             .try_get::<&str, _>("venue_order_id")
@@ -286,7 +283,7 @@ impl<'r> FromRow<'r, PgRow> for OrderAcceptedModel {
             trader_id,
             strategy_id,
             instrument_id,
-            order_id,
+            client_order_id,
             venue_order_id,
             account_id,
             event_id,
@@ -338,8 +335,8 @@ impl<'r> FromRow<'r, PgRow> for OrderFilledModel {
         let instrument_id = row
             .try_get::<&str, _>("instrument_id")
             .map(InstrumentId::from)?;
-        let order_id = row
-            .try_get::<&str, _>("order_id")
+        let client_order_id = row
+            .try_get::<&str, _>("client_order_id")
             .map(ClientOrderId::from)?;
         let venue_order_id = row
             .try_get::<&str, _>("venue_order_id")
@@ -372,7 +369,7 @@ impl<'r> FromRow<'r, PgRow> for OrderFilledModel {
             trader_id,
             strategy_id,
             instrument_id,
-            order_id,
+            client_order_id,
             venue_order_id,
             account_id,
             trade_id,
@@ -433,7 +430,7 @@ impl<'r> FromRow<'r, PgRow> for OrderSubmittedModel {
             .try_get::<&str, _>("instrument_id")
             .map(InstrumentId::from)?;
         let client_order_id = row
-            .try_get::<&str, _>("order_id")
+            .try_get::<&str, _>("client_order_id")
             .map(ClientOrderId::from)?;
         let account_id = row.try_get::<&str, _>("account_id").map(AccountId::from)?;
         let event_id = row.try_get::<&str, _>("id").map(UUID4::from)?;
