@@ -106,6 +106,7 @@ static XMR_LOCK: OnceLock<Currency> = OnceLock::new();
 static XRP_LOCK: OnceLock<Currency> = OnceLock::new();
 static XTZ_LOCK: OnceLock<Currency> = OnceLock::new();
 static USDC_LOCK: OnceLock<Currency> = OnceLock::new();
+static USDC_POS_LOCK: OnceLock<Currency> = OnceLock::new();
 static USDP_LOCK: OnceLock<Currency> = OnceLock::new();
 static USDT_LOCK: OnceLock<Currency> = OnceLock::new();
 static ZEC_LOCK: OnceLock<Currency> = OnceLock::new();
@@ -951,8 +952,8 @@ impl Currency {
         })
     }
 
-    #[allow(non_snake_case)]
     #[must_use]
+    #[allow(non_snake_case)]
     pub fn USDC() -> Self {
         *USDC_LOCK.get_or_init(|| Self {
             code: Ustr::from("USDC"),
@@ -963,6 +964,18 @@ impl Currency {
         })
     }
 
+    #[must_use]
+    #[allow(non_snake_case)]
+    pub fn USDC_POS() -> Self {
+        *USDC_POS_LOCK.get_or_init(|| Self {
+            code: Ustr::from("USDC.e"),
+            precision: 6,
+            iso4217: 0,
+            name: Ustr::from("USD Coin (PoS)"),
+            currency_type: CurrencyType::Crypto,
+        })
+    }
+
     #[allow(non_snake_case)]
     #[must_use]
     pub fn USDP() -> Self {
@@ -1063,6 +1076,7 @@ pub static CURRENCY_MAP: Lazy<Mutex<HashMap<String, Currency>>> = Lazy::new(|| {
     map.insert(Currency::XRP().code.to_string(), Currency::XRP());
     map.insert(Currency::XTZ().code.to_string(), Currency::XTZ());
     map.insert(Currency::USDC().code.to_string(), Currency::USDC());
+    map.insert(Currency::USDC_POS().code.to_string(), Currency::USDC_POS());
     map.insert(Currency::USDP().code.to_string(), Currency::USDP());
     map.insert(Currency::USDT().code.to_string(), Currency::USDT());
     map.insert(Currency::ZEC().code.to_string(), Currency::ZEC());
