@@ -26,10 +26,8 @@ use futures_util::{
     stream::{SplitSink, SplitStream},
     SinkExt, StreamExt,
 };
-use hyper::header::HeaderName;
-use nautilus_core::python::{to_pyruntime_err, to_pyvalue_err};
+use nautilus_cryptography::providers::install_cryptographic_provider;
 use pyo3::{prelude::*, types::PyBytes};
-use rustls::crypto::{aws_lc_rs, CryptoProvider};
 use tokio::{net::TcpStream, sync::Mutex, task, time::sleep};
 use tokio_tungstenite::{
     connect_async,
@@ -37,6 +35,7 @@ use tokio_tungstenite::{
     MaybeTlsStream, WebSocketStream,
 };
 
+use crate::ratelimiter::{clock::MonotonicClock, quota::Quota, RateLimiter};
 type MessageWriter = SplitSink<WebSocketStream<MaybeTlsStream<TcpStream>>, Message>;
 type SharedMessageWriter =
     Arc<Mutex<SplitSink<WebSocketStream<MaybeTlsStream<TcpStream>>, Message>>>;
@@ -49,11 +48,12 @@ type MessageReader = SplitStream<WebSocketStream<MaybeTlsStream<TcpStream>>>;
 )]
 pub struct WebSocketConfig {
     pub url: String,
-    pub handler: PyObject,
+    pub handler: Arc<PyObject>,
     pub headers: Vec<(String, String)>,
     pub heartbeat: Option<u64>,
     pub heartbeat_msg: Option<String>,
-    pub ping_handler: Option<PyObject>,
+    pub ping_handler: Option<Arc<PyObject>>,
+    pub max_reconnection_tries: Option<u64>,
 }
 
 /// `WebSocketClient` connects to a websocket server to read and send messages.
@@ -81,12 +81,9 @@ struct WebSocketClientInner {
 impl WebSocketClientInner {
     /// Create an inner websocket client.
     pub async fn connect_url(config: WebSocketConfig) -> Result<Self, Error> {
-        if CryptoProvider::get_default().is_none() {
-            aws_lc_rs::default_provider()
-                .install_default()
-                .expect("Error installing crypto provider");
-        }
+        install_cryptographic_provider();
 
+        #[allow(unused_variables)]
         let WebSocketConfig {
             url,
             handler,
@@ -94,6 +91,7 @@ impl WebSocketClientInner {
             headers,
             heartbeat_msg,
             ping_handler,
+            max_reconnection_tries,
         } = &config;
         let (writer, reader) = Self::connect_with_server(url, headers.clone()).await?;
         let writer = Arc::new(Mutex::new(writer));
@@ -122,9 +120,9 @@ impl WebSocketClientInner {
 
         // Hacky solution to overcome the new `http` trait bounds
         for (key, val) in headers {
-            let header_value = HeaderValue::from_str(&val).unwrap();
+            let header_value = HeaderValue::from_str(&val)?;
             use http::header::HeaderName;
-            let header_name: HeaderName = key.parse().unwrap();
+            let header_name: HeaderName = key.parse()?;
             let header_name_string = header_name.to_string();
             let header_name_str: &'static str = Box::leak(header_name_string.into_boxed_str());
             req_headers.insert(header_name_str, header_value);
@@ -162,18 +160,18 @@ impl WebSocketClientInner {
     /// Keep receiving messages from socket and pass them as arguments to handler.
     pub fn spawn_read_task(
         mut reader: MessageReader,
-        handler: PyObject,
-        ping_handler: Option<PyObject>,
+        handler: Arc<PyObject>,
+        ping_handler: Option<Arc<PyObject>>,
     ) -> task::JoinHandle<()> {
         tracing::debug!("Started task 'read'");
         task::spawn(async move {
             loop {
                 match reader.next().await {
                     Some(Ok(Message::Binary(data))) => {
-                        tracing::trace!("Received message <binary>");
-                        if let Err(e) =
-                            Python::with_gil(|py| handler.call1(py, (PyBytes::new(py, &data),)))
-                        {
+                        tracing::trace!("Received message <binary> {} bytes", data.len());
+                        if let Err(e) = Python::with_gil(|py| {
+                            handler.call1(py, (PyBytes::new_bound(py, &data),))
+                        }) {
                             tracing::error!("Error calling handler: {e}");
                             break;
                         }
@@ -182,7 +180,7 @@ impl WebSocketClientInner {
                     Some(Ok(Message::Text(data))) => {
                         tracing::trace!("Received message: {data}");
                         if let Err(e) = Python::with_gil(|py| {
-                            handler.call1(py, (PyBytes::new(py, data.as_bytes()),))
+                            handler.call1(py, (PyBytes::new_bound(py, data.as_bytes()),))
                         }) {
                             tracing::error!("Error calling handler: {e}");
                             break;
@@ -193,9 +191,9 @@ impl WebSocketClientInner {
                         let payload = String::from_utf8(ping.clone()).expect("Invalid payload");
                         tracing::trace!("Received ping: {payload}",);
                         if let Some(ref handler) = ping_handler {
-                            if let Err(e) =
-                                Python::with_gil(|py| handler.call1(py, (PyBytes::new(py, &ping),)))
-                            {
+                            if let Err(e) = Python::with_gil(|py| {
+                                handler.call1(py, (PyBytes::new_bound(py, &ping),))
+                            }) {
                                 tracing::error!("Error calling handler: {e}");
                                 break;
                             }
@@ -249,8 +247,11 @@ impl WebSocketClientInner {
 
         tracing::debug!("Closing writer");
         let mut write_half = self.writer.lock().await;
-        write_half.close().await.unwrap();
-        tracing::debug!("Closed connection");
+        if let Err(e) = write_half.close().await {
+            tracing::error!("Error closing writer: {e:?}");
+        } else {
+            tracing::debug!("Closed connection");
+        }
     }
 
     /// Reconnect with server.
@@ -258,6 +259,8 @@ impl WebSocketClientInner {
     /// Make a new connection with server. Use the new read and write halves
     /// to update self writer and read and heartbeat tasks.
     pub async fn reconnect(&mut self) -> Result<(), Error> {
+        self.shutdown().await;
+
         let (new_writer, reader) =
             Self::connect_with_server(&self.config.url, self.config.headers.clone()).await?;
         let mut guard = self.writer.lock().await;
@@ -269,6 +272,7 @@ impl WebSocketClientInner {
             self.config.handler.clone(),
             self.config.ping_handler.clone(),
         );
+
         self.heartbeat_task = Self::spawn_heartbeat_task(
             self.config.heartbeat,
             self.config.heartbeat_msg.clone(),
@@ -312,6 +316,7 @@ impl Drop for WebSocketClientInner {
     pyo3::pyclass(module = "nautilus_trader.core.nautilus_pyo3.network")
 )]
 pub struct WebSocketClient {
+    pub(crate) rate_limiter: Arc<RateLimiter<String, MonotonicClock>>,
     pub(crate) writer: SharedMessageWriter,
     pub(crate) controller_task: task::JoinHandle<()>,
     pub(crate) disconnect_mode: Arc<AtomicBool>,
@@ -327,9 +332,11 @@ impl WebSocketClient {
         post_connection: Option<PyObject>,
         post_reconnection: Option<PyObject>,
         post_disconnection: Option<PyObject>,
+        keyed_quotas: Vec<(String, Quota)>,
+        default_quota: Option<Quota>,
     ) -> Result<Self, Error> {
         tracing::debug!("Connecting");
-        let inner = WebSocketClientInner::connect_url(config).await?;
+        let inner = WebSocketClientInner::connect_url(config.clone()).await?;
         let writer = inner.writer.clone();
         let disconnect_mode = Arc::new(AtomicBool::new(false));
 
@@ -338,7 +345,9 @@ impl WebSocketClient {
             disconnect_mode.clone(),
             post_reconnection,
             post_disconnection,
+            config.max_reconnection_tries,
         );
+        let rate_limiter = Arc::new(RateLimiter::new_with_quota(default_quota, keyed_quotas));
 
         if let Some(handler) = post_connection {
             Python::with_gil(|py| match handler.call0(py) {
@@ -348,6 +357,7 @@ impl WebSocketClient {
         };
 
         Ok(Self {
+            rate_limiter,
             writer,
             controller_task,
             disconnect_mode,
@@ -374,7 +384,7 @@ impl WebSocketClient {
         })
         .await
         {
-            Ok(_) => {
+            Ok(()) => {
                 tracing::debug!("Controller task finished");
             }
             Err(_) => {
@@ -384,7 +394,7 @@ impl WebSocketClient {
     }
 
     pub async fn send_bytes(&self, data: Vec<u8>) -> Result<(), Error> {
-        tracing::trace!("Sending bytes: {:?}", data);
+        tracing::trace!("Sending bytes: {data:?}");
         let mut guard = self.writer.lock().await;
         guard.send(Message::Binary(data)).await
     }
@@ -402,8 +412,10 @@ impl WebSocketClient {
         disconnect_mode: Arc<AtomicBool>,
         post_reconnection: Option<PyObject>,
         post_disconnection: Option<PyObject>,
+        max_reconnection_tries: Option<u64>,
     ) -> task::JoinHandle<()> {
         task::spawn(async move {
+            let mut retry_counter: u64 = 0;
             loop {
                 sleep(Duration::from_millis(100)).await;
 
@@ -413,6 +425,8 @@ impl WebSocketClient {
                     (false, false) => match inner.reconnect().await {
                         Ok(()) => {
                             tracing::debug!("Reconnected successfully");
+                            retry_counter = 0;
+
                             if let Some(ref handler) = post_reconnection {
                                 Python::with_gil(|py| match handler.call0(py) {
                                     Ok(_) => tracing::debug!("Called `post_reconnection` handler"),
@@ -425,8 +439,19 @@ impl WebSocketClient {
                             }
                         }
                         Err(e) => {
-                            tracing::error!("Reconnect failed {e}");
-                            break;
+                            if let Some(max_reconnection_tries) = max_reconnection_tries {
+                                if retry_counter < max_reconnection_tries {
+                                    retry_counter += 1;
+                                    tracing::warn!("Reconnect failed {e}. Retry {retry_counter}/{max_reconnection_tries}");
+                                    sleep(Duration::from_millis(1000)).await;
+                                } else {
+                                    tracing::error!("Reconnect failed {e}");
+                                    break;
+                                }
+                            } else {
+                                tracing::error!("Reconnect failed {e}");
+                                break;
+                            }
                         }
                     },
                     (true, true) => {
@@ -448,7 +473,7 @@ impl WebSocketClient {
                     (true, false) => {
                         tracing::debug!("Inner client is disconnected");
                         tracing::debug!("Shutting down inner client to clean up running tasks");
-                        inner.shutdown().await
+                        inner.shutdown().await;
                     }
                     _ => (),
                 }
