@@ -23,7 +23,6 @@ from nautilus_trader.adapters.binance.common.constants import BINANCE_MIN_CALLBA
 from nautilus_trader.adapters.binance.common.constants import BINANCE_VENUE
 from nautilus_trader.adapters.binance.common.enums import BinanceAccountType
 from nautilus_trader.adapters.binance.common.enums import BinanceEnumParser
-from nautilus_trader.adapters.binance.common.enums import BinanceErrorCode
 from nautilus_trader.adapters.binance.common.enums import BinanceFuturesPositionSide
 from nautilus_trader.adapters.binance.common.enums import BinanceTimeInForce
 from nautilus_trader.adapters.binance.common.schemas.account import BinanceOrder
@@ -74,7 +73,6 @@ from nautilus_trader.model.identifiers import ClientOrderId
 from nautilus_trader.model.identifiers import InstrumentId
 from nautilus_trader.model.identifiers import PositionId
 from nautilus_trader.model.identifiers import Symbol
-from nautilus_trader.model.identifiers import Venue
 from nautilus_trader.model.identifiers import VenueOrderId
 from nautilus_trader.model.objects import Price
 from nautilus_trader.model.objects import Quantity
@@ -148,7 +146,7 @@ class BinanceCommonExecutionClient(LiveExecutionClient):
         super().__init__(
             loop=loop,
             client_id=ClientId(name or BINANCE_VENUE.value),
-            venue=Venue(name or BINANCE_VENUE.value),
+            venue=BINANCE_VENUE,
             oms_type=OmsType.HEDGING if account_type.is_futures else OmsType.NETTING,
             instrument_provider=instrument_provider,
             account_type=AccountType.CASH if account_type.is_spot else AccountType.MARGIN,
@@ -191,7 +189,7 @@ class BinanceCommonExecutionClient(LiveExecutionClient):
         self._http_user = user
 
         # Listen keys
-        self._ping_listen_keys_interval: int = 60 * 5  # Once every 5 mins (hardcode)
+        self._ping_listen_keys_interval: int = 60 * 5  # Once every 5 mins (hard-coded)
         self._ping_listen_keys_task: asyncio.Task | None = None
         self._listen_key: str | None = None
 
@@ -261,16 +259,11 @@ class BinanceCommonExecutionClient(LiveExecutionClient):
 
     async def _connect(self) -> None:
         try:
-            # Initialize instrument provider
             await self._instrument_provider.initialize()
 
-            # Authenticate API key and update account(s)
             await self._update_account_state()
-
-            # Set dual side position
             await self._init_dual_side_position()
 
-            # Get listen keys
             response: BinanceListenKey = await self._http_user.create_listen_key()
         except BinanceError as e:
             self._log.exception(f"Error on connect: {e.message}", e)
@@ -448,7 +441,7 @@ class BinanceCommonExecutionClient(LiveExecutionClient):
         end: pd.Timestamp | None = None,
         open_only: bool = False,
     ) -> list[OrderStatusReport]:
-        self._log.info("Requesting OrderStatusReports...")
+        self._log.debug("Requesting OrderStatusReports...")
 
         try:
             # Check Binance for all order active symbols
@@ -460,13 +453,16 @@ class BinanceCommonExecutionClient(LiveExecutionClient):
                 active_symbols.add(order.symbol)
             # Get all orders for those active symbols
             binance_orders: list[BinanceOrder] = []
-            for symbol in active_symbols:
-                # Here we don't pass a `start_time` or `end_time` as order reports appear to go
-                # randomly missing when these are specified. We filter on the Nautilus side below.
-                # Explicitly setting limit to the max lookback of 1000, in the future we should
-                # add pagination.
-                response = await self._http_account.query_all_orders(symbol=symbol, limit=1_000)
-                binance_orders.extend(response)
+            if open_only:
+                binance_orders = binance_open_orders
+            else:
+                for symbol in active_symbols:
+                    # Here we don't pass a `start_time` or `end_time` as order reports appear to go
+                    # randomly missing when these are specified. We filter on the Nautilus side below.
+                    # Explicitly setting limit to the max lookback of 1000, in the future we should
+                    # add pagination.
+                    response = await self._http_account.query_all_orders(symbol=symbol, limit=1_000)
+                    binance_orders.extend(response)
         except BinanceError as e:
             self._log.exception(f"Cannot generate OrderStatusReport: {e.message}", e)
             return []
@@ -506,7 +502,7 @@ class BinanceCommonExecutionClient(LiveExecutionClient):
         start: pd.Timestamp | None = None,
         end: pd.Timestamp | None = None,
     ) -> list[FillReport]:
-        self._log.info("Requesting FillReports...")
+        self._log.debug("Requesting FillReports...")
 
         try:
             # Check Binance for all trades on active symbols
@@ -574,7 +570,7 @@ class BinanceCommonExecutionClient(LiveExecutionClient):
                     )
                     reports = [report]
             else:
-                self._log.info("Requesting PositionStatusReports...")
+                self._log.debug("Requesting PositionStatusReports...")
                 reports = await self._get_binance_position_status_reports()
         except BinanceError as e:
             self._log.exception(f"Cannot generate PositionStatusReport: {e.message}", e)
@@ -904,7 +900,6 @@ class BinanceCommonExecutionClient(LiveExecutionClient):
         )
 
     def _get_cached_instrument_id(self, symbol: str) -> InstrumentId:
-        # Parse instrument ID
         nautilus_symbol: str = BinanceSymbol(symbol).parse_as_nautilus(
             self._binance_account_type,
         )
@@ -944,6 +939,15 @@ class BinanceCommonExecutionClient(LiveExecutionClient):
                 quantity=str(command.quantity) if command.quantity else str(order.quantity),
                 price=str(command.price) if command.price else str(order.price),
             )
+            if not retry_manager.result:
+                self.generate_order_modify_reject(
+                    command.strategy_id,
+                    command.instrument_id,
+                    command.client_order_id,
+                    command.venue_order_id,
+                    retry_manager.message,
+                    self._clock.timestamp_ns(),
+                )
 
     async def _cancel_order(self, command: CancelOrder) -> None:
         async with self._retry_manager_pool as retry_manager:
@@ -955,6 +959,15 @@ class BinanceCommonExecutionClient(LiveExecutionClient):
                 client_order_id=command.client_order_id,
                 venue_order_id=command.venue_order_id,
             )
+            if not retry_manager.result:
+                self.generate_order_cancel_rejected(
+                    command.strategy_id,
+                    command.instrument_id,
+                    command.client_order_id,
+                    command.venue_order_id,
+                    retry_manager.message,
+                    self._clock.timestamp_ns(),
+                )
 
     async def _cancel_all_orders(self, command: CancelAllOrders) -> None:
         open_orders_strategy: list[Order] = self._cache.orders_open(
@@ -967,26 +980,56 @@ class BinanceCommonExecutionClient(LiveExecutionClient):
             instrument_id=command.instrument_id,
         )
 
-        try:
-            if open_orders_total_count == len(open_orders_strategy):
-                await self._http_account.cancel_all_open_orders(
+        if open_orders_total_count == len(open_orders_strategy):
+            async with self._retry_manager_pool as retry_manager:
+                await retry_manager.run(
+                    "cancel_all_open_orders",
+                    [command.instrument_id],
+                    self._http_account.cancel_all_open_orders,
                     symbol=command.instrument_id.symbol.value,
                 )
-            else:
-                for order in open_orders_strategy:
-                    await self._cancel_order_single(
-                        instrument_id=order.instrument_id,
-                        client_order_id=order.client_order_id,
-                        venue_order_id=order.venue_order_id,
-                    )
-        except BinanceError as e:
-            if "Unknown order sent" in e.message:
-                self._log.info(
-                    "No open orders to cancel according to Binance",
-                    LogColor.GREEN,
+                if not retry_manager.result:
+                    if retry_manager.message is not None:
+                        if "Unknown order sent" in retry_manager.message:
+                            self._log.info(
+                                "No open orders to cancel according to Binance",
+                                LogColor.GREEN,
+                            )
+                            return
+                    for order in open_orders_strategy:
+                        if order.is_closed:
+                            continue
+                        self.generate_order_cancel_rejected(
+                            order.strategy_id,
+                            order.instrument_id,
+                            order.client_order_id,
+                            order.venue_order_id,
+                            retry_manager.message,
+                            self._clock.timestamp_ns(),
+                        )
+                return
+
+        # Not every strategy order is included in all orders - so must cancel individually
+        # TODO: A future improvement could be to asyncio.gather all cancel tasks
+        for order in open_orders_strategy:
+            async with self._retry_manager_pool as retry_manager:
+                await retry_manager.run(
+                    "cancel_order",
+                    [order.client_order_id, order.venue_order_id],
+                    self._cancel_order_single,
+                    instrument_id=order.instrument_id,
+                    client_order_id=order.client_order_id,
+                    venue_order_id=order.venue_order_id,
                 )
-            else:
-                self._log.exception(f"Cannot cancel open orders: {e.message}", e)
+                if not retry_manager.result:
+                    self.generate_order_cancel_rejected(
+                        order.strategy_id,
+                        order.instrument_id,
+                        order.client_order_id,
+                        order.venue_order_id,
+                        retry_manager.message,
+                        self._clock.timestamp_ns(),
+                    )
 
     async def _cancel_order_single(
         self,
@@ -1006,24 +1049,11 @@ class BinanceCommonExecutionClient(LiveExecutionClient):
             )
             return
 
-        try:
-            await self._http_account.cancel_order(
-                symbol=instrument_id.symbol.value,
-                order_id=int(venue_order_id.value) if venue_order_id else None,
-                orig_client_order_id=client_order_id.value if client_order_id else None,
-            )
-        except BinanceError as e:
-            error_code = BinanceErrorCode(e.message["code"])
-            if error_code == BinanceErrorCode.CANCEL_REJECTED:
-                self._log.warning(f"Cancel rejected: {e.message}")
-            else:
-                self._log.exception(
-                    f"Cannot cancel order "
-                    f"{client_order_id!r}, "
-                    f"{venue_order_id!r}: "
-                    f"{e.message}",
-                    e,
-                )
+        await self._http_account.cancel_order(
+            symbol=instrument_id.symbol.value,
+            order_id=int(venue_order_id.value) if venue_order_id else None,
+            orig_client_order_id=client_order_id.value if client_order_id else None,
+        )
 
     # -- WEBSOCKET EVENT HANDLERS -----------------------------------------------------------------
 
