@@ -159,15 +159,9 @@ class BybitExecutionClient(LiveExecutionClient):
         # Configuration
         self._product_types = product_types
         self._use_gtd = config.use_gtd
-        self._use_reduce_only = config.use_reduce_only
-        self._use_position_ids = config.use_position_ids
-        self._max_retries = config.max_retries or 0
-        self._retry_delay = config.retry_delay or 1.0
         self._log.info(f"Account type: {account_type_to_str(account_type)}", LogColor.BLUE)
         self._log.info(f"Product types: {[p.value for p in product_types]}", LogColor.BLUE)
         self._log.info(f"{config.use_gtd=}", LogColor.BLUE)
-        self._log.info(f"{config.use_reduce_only=}", LogColor.BLUE)
-        self._log.info(f"{config.use_position_ids=}", LogColor.BLUE)
         self._log.info(f"{config.max_retries=}", LogColor.BLUE)
         self._log.info(f"{config.retry_delay=}", LogColor.BLUE)
 
@@ -230,6 +224,7 @@ class BybitExecutionClient(LiveExecutionClient):
         )
 
     async def _connect(self) -> None:
+        await self._instrument_provider.initialize()
         await self._update_account_state()
 
         await self._ws_client.connect()
@@ -251,7 +246,7 @@ class BybitExecutionClient(LiveExecutionClient):
         end: pd.Timestamp | None = None,
         open_only: bool = False,
     ) -> list[OrderStatusReport]:
-        self._log.info("Requesting OrderStatusReports...")
+        self._log.debug("Requesting OrderStatusReports...")
         reports: list[OrderStatusReport] = []
 
         try:
@@ -261,7 +256,11 @@ class BybitExecutionClient(LiveExecutionClient):
             # active_symbols.update(await self._get_active_position_symbols(symbol))
             # open_orders: dict[BybitProductType, list[BybitOrder]] = dict()
             for product_type in self._product_types:
-                bybit_orders = await self._http_account.query_order_history(product_type, symbol)
+                bybit_orders = await self._http_account.query_order_history(
+                    product_type,
+                    symbol,
+                    open_only,
+                )
                 for bybit_order in bybit_orders:
                     # Uncomment for development
                     # self._log.info(f"Generating report {bybit_order}", LogColor.MAGENTA)
@@ -364,7 +363,7 @@ class BybitExecutionClient(LiveExecutionClient):
         start: pd.Timestamp | None = None,
         end: pd.Timestamp | None = None,
     ) -> list[FillReport]:
-        self._log.info("Requesting FillReports...")
+        self._log.debug("Requesting FillReports...")
         reports: list[FillReport] = []
 
         try:
@@ -409,7 +408,7 @@ class BybitExecutionClient(LiveExecutionClient):
 
         try:
             if instrument_id:
-                self._log.info(f"Requesting PositionStatusReport for {instrument_id}")
+                self._log.debug(f"Requesting PositionStatusReport for {instrument_id}")
                 bybit_symbol = BybitSymbol(instrument_id.symbol.value)
                 positions = await self._http_account.query_position_info(
                     bybit_symbol.product_type,
@@ -425,7 +424,7 @@ class BybitExecutionClient(LiveExecutionClient):
                     self._log.debug(f"Received {position_report}")
                     reports.append(position_report)
             else:
-                self._log.info("Requesting PositionStatusReports...")
+                self._log.debug("Requesting PositionStatusReports...")
                 for product_type in self._product_types:
                     if product_type == BybitProductType.SPOT:
                         continue  # No positions on spot
@@ -545,6 +544,15 @@ class BybitExecutionClient(LiveExecutionClient):
                 client_order_id=client_order_id,
                 venue_order_id=venue_order_id,
             )
+            if not retry_manager.result:
+                self.generate_order_cancel_rejected(
+                    order.strategy_id,
+                    order.instrument_id,
+                    order.client_order_id,
+                    order.venue_order_id,
+                    retry_manager.message,
+                    self._clock.timestamp_ns(),
+                )
 
     async def _batch_cancel_orders(self, command: BatchCancelOrders) -> None:
         # https://bybit-exchange.github.io/docs/v5/order/batch-cancel
@@ -589,6 +597,19 @@ class BybitExecutionClient(LiveExecutionClient):
                     product_type=product_type,
                     cancel_orders=cancel_orders,
                 )
+                if not retry_manager.result:
+                    for cancel in batch_cancels:
+                        order = self._cache.order(cancel.client_order_id)
+                        if order is None or order.is_closed:
+                            continue
+                        self.generate_order_cancel_rejected(
+                            order.strategy_id,
+                            order.instrument_id,
+                            order.client_order_id,
+                            order.venue_order_id,
+                            retry_manager.message,
+                            self._clock.timestamp_ns(),
+                        )
 
     async def _cancel_all_orders(self, command: CancelAllOrders) -> None:
         bybit_symbol = BybitSymbol(command.instrument_id.symbol.value)
@@ -601,6 +622,19 @@ class BybitExecutionClient(LiveExecutionClient):
                 product_type=bybit_symbol.product_type,
                 symbol=bybit_symbol.raw_symbol,
             )
+            if not retry_manager.result:
+                orders_open = self._cache.orders_open(instrument_id=command.instrument_id)
+                for order in orders_open:
+                    if order.is_closed:
+                        continue
+                    self.generate_order_cancel_rejected(
+                        order.strategy_id,
+                        order.instrument_id,
+                        order.client_order_id,
+                        order.venue_order_id,
+                        retry_manager.message,
+                        self._clock.timestamp_ns(),
+                    )
 
     async def _modify_order(self, command: ModifyOrder) -> None:
         order: Order | None = self._cache.order(command.client_order_id)
@@ -635,6 +669,15 @@ class BybitExecutionClient(LiveExecutionClient):
                 quantity=quantity,
                 price=price,
             )
+            if not retry_manager.result:
+                self.generate_order_modify_rejected(
+                    order.strategy_id,
+                    order.instrument_id,
+                    order.client_order_id,
+                    order.venue_order_id,
+                    retry_manager.message,
+                    self._clock.timestamp_ns(),
+                )
 
     async def _submit_order(self, command: SubmitOrder) -> None:
         order = command.order
