@@ -36,6 +36,8 @@ class DatabentoDataLoader:
      - MBO -> `OrderBookDelta`
      - MBP_1 -> `(QuoteTick, TradeTick | None)`
      - MBP_10 -> `OrderBookDepth10`
+     - BBO_1S -> `QuoteTick`
+     - BBO_1M -> `QuoteTick`
      - TBBO -> `(QuoteTick, TradeTick)`
      - TRADES -> `TradeTick`
      - OHLCV_1S -> `Bar`
@@ -49,7 +51,7 @@ class DatabentoDataLoader:
 
     References
     ----------
-    https://databento.com/docs/knowledge-base/new-users/dbn-encoding
+    https://databento.com/docs/schemas-and-data-formats
 
     """
 
@@ -104,6 +106,10 @@ class DatabentoDataLoader:
         if dataset is None:
             raise ValueError(f"No Databento dataset for venue '{venue}'")
 
+        # TODO: Temporary workaround
+        if dataset == "XNAS.BASIC":
+            return "XNAS.ITCH"
+
         return dataset
 
     def from_dbn_file(  # noqa: C901 (too complex)
@@ -210,6 +216,21 @@ class DatabentoDataLoader:
                         filepath=str(path),
                         instrument_id=pyo3_instrument_id,
                     )
+            case DatabentoSchema.BBO_1S.value | DatabentoSchema.BBO_1M.value:
+                if as_legacy_cython:
+                    capsule = self._pyo3_loader.load_bbo_quotes_as_pycapsule(
+                        filepath=str(path),
+                        instrument_id=pyo3_instrument_id,
+                    )
+                    data = capsule_to_list(capsule)
+                    # Drop encapsulated `CVec` as data is now transferred
+                    drop_cvec_pycapsule(capsule)
+                    return data
+                else:
+                    return self._pyo3_loader.load_bbo_quotes(
+                        filepath=str(path),
+                        instrument_id=pyo3_instrument_id,
+                    )
             case DatabentoSchema.MBP_10.value:
                 if as_legacy_cython:
                     capsule = self._pyo3_loader.load_order_book_depth10_as_pycapsule(
