@@ -550,14 +550,14 @@ class DYDXWsSubaccountsSubscribedContents(msgspec.Struct, forbid_unknown_fields=
         """
         orders: dict[str, list[DYDXOrderResponse]] = defaultdict(list)
 
+        # Orders with state BEST_EFFORT_CANCELED are not considered to be
+        # included in the locked account balance.
         if self.orders is not None:
             for order in self.orders:
                 if (
                     order.status
                     in (
                         DYDXOrderStatus.OPEN,
-                        DYDXOrderStatus.BEST_EFFORT_CANCELED,
-                        DYDXOrderStatus.UNTRIGGERED,
                         DYDXOrderStatus.BEST_EFFORT_OPENED,
                     )
                     and order.type == DYDXOrderType.LIMIT
@@ -655,6 +655,7 @@ class DYDXWsFillSubaccountMessageContents(msgspec.Struct, forbid_unknown_fields=
     orderId: str | None = None
     clientMetadata: str | None = None
     fee: str | None = None
+    affiliateRevShare: str | None = None
 
 
 class DYDXWsOrderSubaccountMessageContents(msgspec.Struct, forbid_unknown_fields=True):
