@@ -19,7 +19,6 @@ Provide a dYdX streaming WebSocket client.
 import asyncio
 from collections.abc import Awaitable
 from collections.abc import Callable
-from datetime import timedelta
 from typing import Any
 
 import msgspec
@@ -28,8 +27,8 @@ import pandas as pd
 from nautilus_trader.adapters.dydx.common.enums import DYDXCandlesResolution
 from nautilus_trader.common.component import LiveClock
 from nautilus_trader.common.component import Logger
-from nautilus_trader.common.component import Throttler
 from nautilus_trader.common.enums import LogColor
+from nautilus_trader.core.nautilus_pyo3 import Quota
 from nautilus_trader.core.nautilus_pyo3 import WebSocketClient
 from nautilus_trader.core.nautilus_pyo3 import WebSocketClientError
 from nautilus_trader.core.nautilus_pyo3 import WebSocketConfig
@@ -49,6 +48,10 @@ class DYDXWebsocketClient:
         The callback handler for message events.
     handler_reconnect : Callable[..., Awaitable[None]], optional
         The callback handler to be called on reconnect.
+    loop : asyncio.AbstractEventLoop
+        The event loop for the client.
+    subscription_rate_limit_per_second : int, default 2
+        The maximum number of subscription message to send to the venue.
 
     """
 
@@ -73,17 +76,9 @@ class DYDXWebsocketClient:
         self._client: WebSocketClient | None = None
         self._is_running = False
         self._subscriptions: set[tuple[str, str]] = set()
-
-        self._subscribe_throttler = Throttler(
-            name="dydx_websocket_subscribe_throttler",
-            limit=subscription_rate_limit_per_second,
-            interval=timedelta(seconds=1),
-            clock=self._clock,
-            output_send=self._send_subscribe_msg,
-        )
-
+        self._subscription_rate_limit_per_second = subscription_rate_limit_per_second
         self._msg_timestamp = self._clock.utc_now()
-        self._msg_interval_secs: int = 60
+        self._msg_timeout_secs: int = 60
         self._reconnect_task: asyncio.Task | None = None
 
     def is_connected(self) -> bool:
@@ -111,13 +106,30 @@ class DYDXWebsocketClient:
     @property
     def subscriptions(self) -> set[tuple[str, str]]:
         """
-        Return the list of subscriptions.
+        Return the set of subscriptions.
+
+        Returns
+        -------
+        set[tuple[str, str]]
+            Set of subscriptions.
+
         """
         return self._subscriptions
 
     def has_subscription(self, item: tuple[str, str]) -> bool:
         """
         Return true if the connection is already subscribed to this topic.
+
+        Parameters
+        ----------
+        item : tuple[str, str]
+            Topic name.
+
+        Returns
+        -------
+        bool
+            Whether the client is already subscribed to this topic.
+
         """
         return item in self._subscriptions
 
@@ -137,6 +149,7 @@ class DYDXWebsocketClient:
         client = await WebSocketClient.connect(
             config=config,
             post_reconnection=self.reconnect,
+            default_quota=Quota.rate_per_second(self._subscription_rate_limit_per_second),
         )
         self._client = client
         self._log.info(f"Connected to {self._base_url}", LogColor.BLUE)
@@ -147,10 +160,28 @@ class DYDXWebsocketClient:
             self._reconnect_task = self._loop.create_task(self._reconnect_guard())
 
     def _msg_handler(self, raw: bytes) -> None:
+        """
+        Handle pushed websocket messages.
+
+        Parameters
+        ----------
+        raw : bytes
+            The received message in bytes.
+
+        """
         self._msg_timestamp = self._clock.utc_now()
         self._handler(raw)
 
     def _handle_ping(self, raw: bytes) -> None:
+        """
+        Handle ping messages by returning a pong message.
+
+        Parameters
+        ----------
+        raw : bytes
+            The received ping in bytes.
+
+        """
         self._loop.create_task(self.send_pong(raw))
 
     async def send_pong(self, raw: bytes) -> None:
@@ -160,7 +191,10 @@ class DYDXWebsocketClient:
         if self._client is None:
             return
 
-        await self._client.send_pong(raw)
+        try:
+            await self._client.send_pong(raw)
+        except WebSocketClientError as e:
+            self._log.error(str(e))
 
     async def _reconnect_guard(self) -> None:
         """
@@ -169,28 +203,34 @@ class DYDXWebsocketClient:
         """
         try:
             while True:
-                self._log.debug(
-                    f"Scheduled `reconnect_guard` to run in {self._msg_interval_secs}s",
-                )
-                await asyncio.sleep(self._msg_interval_secs)
+                await asyncio.sleep(1)
+                time_since_previous_msg = self._clock.utc_now() - self._msg_timestamp
 
-                now_timestamp = self._clock.utc_now()
-                time_since_previous_msg = now_timestamp - self._msg_timestamp
+                if self.is_disconnected() or time_since_previous_msg > pd.Timedelta(
+                    seconds=self._msg_timeout_secs,
+                ):
+                    if self.is_disconnected():
+                        self._log.error("Websocket disconnected. Reconnecting.")
+
+                    # Print error if no message has been received for twice the timeout time
+                    # to reduce log noise.
+                    if time_since_previous_msg > pd.Timedelta(seconds=2 * self._msg_timeout_secs):
+                        self._log.error(
+                            f"{time_since_previous_msg} since previous received message. Reconnecting.",
+                        )
 
-                if time_since_previous_msg > pd.Timedelta(seconds=self._msg_interval_secs):
-                    self._log.error(
-                        f"Time since previous received message is {time_since_previous_msg}",
-                    )
                     try:
                         await self.disconnect()
                         await self.connect()
                         self.reconnect()
+
+                        self._log.info("Websocket connected")
                     except Exception as e:
                         self._log.error(f"Failed to connect the websocket: {e}")
                         self._client = None
 
         except asyncio.CancelledError:
-            self._log.debug("Canceled `reconnect_guard` task")
+            self._log.debug("Canceled 'reconnect_guard' task")
 
     def reconnect(self) -> None:
         """
@@ -229,6 +269,12 @@ class DYDXWebsocketClient:
     async def subscribe_trades(self, symbol: str) -> None:
         """
         Subscribe to trades messages.
+
+        Parameters
+        ----------
+        symbol : str
+            Symbol of the instrument to subscribe to.
+
         """
         if self._client is None:
             self._log.warning("Cannot subscribe to trades: not connected")
@@ -241,8 +287,8 @@ class DYDXWebsocketClient:
 
         self._subscriptions.add(subscription)
         msg = {"type": "subscribe", "channel": "v4_trades", "id": symbol}
-        self._log.debug(f"Subscribe to {symbol} trade ticks")
-        self._subscribe_throttler.send(msg)
+        self._log.debug(f"Subscribe to {symbol} trades")
+        await self._send(msg)
 
     async def subscribe_order_book(
         self,
@@ -250,7 +296,16 @@ class DYDXWebsocketClient:
         bypass_subscription_validation: bool = False,
     ) -> None:
         """
-        Subscribe to trades messages.
+        Subscribe to order book messages.
+
+        Parameters
+        ----------
+        symbol : str
+            Symbol of the instrument to subscribe to.
+        bypass_subscription_validation : bool, default False
+            Whether to bypass the subscription validation step before sending the
+            subscribe message to the venue.
+
         """
         if self._client is None:
             self._log.warning("Cannot subscribe to order book: not connected")
@@ -264,11 +319,19 @@ class DYDXWebsocketClient:
         self._subscriptions.add(subscription)
         msg = {"type": "subscribe", "channel": "v4_orderbook", "id": symbol, "batched": True}
         self._log.debug(f"Subscribe to {symbol} order book")
-        self._subscribe_throttler.send(msg)
+        await self._send(msg)
 
     async def subscribe_klines(self, symbol: str, interval: DYDXCandlesResolution) -> None:
         """
         Subscribe to klines.
+
+        Parameters
+        ----------
+        symbol : str
+            Symbol of the instrument to subscribe to bars.
+        interval : DYDXCandlesResolution
+            Specify the interval between candle updates (for example 1MIN).
+
         """
         if self._client is None:
             self._log.warning("Cannot subscribe to klines: not connected")
@@ -281,7 +344,7 @@ class DYDXWebsocketClient:
 
         self._subscriptions.add(subscription)
         msg = {"type": "subscribe", "channel": "v4_candles", "id": f"{symbol}/{interval.value}"}
-        self._subscribe_throttler.send(msg)
+        await self._send(msg)
 
     async def subscribe_markets(self) -> None:
         """
@@ -298,12 +361,21 @@ class DYDXWebsocketClient:
 
         self._subscriptions.add((subscription, ""))
         msg = {"type": "subscribe", "channel": "v4_markets"}
-        self._subscribe_throttler.send(msg)
+        await self._send(msg)
 
     async def subscribe_account_update(self, wallet_address: str, subaccount_number: int) -> None:
         """
         Subscribe to realtime information about orders, fills, transfers, perpetual
         positions, and perpetual assets for a subaccount.
+
+        Parameters
+        ----------
+        wallet_address : str
+            The dYdX wallet address.
+        subaccount_number : int
+            The subaccount number.
+            The venue creates subaccount 0 by default.
+
         """
         if self._client is None:
             self._log.warning("Cannot subscribe: not connected")
@@ -319,11 +391,20 @@ class DYDXWebsocketClient:
 
         self._subscriptions.add(subscription)
         msg = {"type": "subscribe", "channel": channel, "id": channel_id}
-        self._subscribe_throttler.send(msg)
+        await self._send(msg)
 
     async def unsubscribe_account_update(self, wallet_address: str, subaccount_number: int) -> None:
         """
-        Unsubscribe from account messages.
+        Unsubscribe from account updates.
+
+        Parameters
+        ----------
+        wallet_address : str
+            The dYdX wallet address.
+        subaccount_number : int
+            The subaccount number.
+            The venue creates subaccount 0 by default.
+
         """
         if self._client is None:
             self._log.warning("Cannot unsubscribe: not connected")
@@ -343,7 +424,13 @@ class DYDXWebsocketClient:
 
     async def unsubscribe_trades(self, symbol: str) -> None:
         """
-        Unsubscribe to trades messages.
+        Unsubscribe from trades messages.
+
+        Parameters
+        ----------
+        symbol : str
+            Symbol of the instrument to unsubscribe from.
+
         """
         if self._client is None:
             self._log.warning("Cannot unsubscribe: not connected")
@@ -360,7 +447,15 @@ class DYDXWebsocketClient:
 
     async def unsubscribe_order_book(self, symbol: str, remove_subscription: bool = True) -> None:
         """
-        Unsubscribe to trades messages.
+        Unsubscribe from order book messages.
+
+        Parameters
+        ----------
+        symbol : str
+            Symbol of the instrument to unsubscribe from.
+        remove_subscription : bool, optional default True
+            Whether to remove the symbol from the list of subscriptions for order book updates.
+
         """
         if self._client is None:
             self._log.warning("Cannot unsubscribe: not connected")
@@ -379,7 +474,15 @@ class DYDXWebsocketClient:
 
     async def unsubscribe_klines(self, symbol: str, interval: DYDXCandlesResolution) -> None:
         """
-        Unsubscribe to trades messages.
+        Unsubscribe from bar messages.
+
+        Parameters
+        ----------
+        symbol : str
+            Symbol of the instrument to unsubscribe from bars.
+        interval : DYDXCandlesResolution
+            Specify the interval between candle updates (for example 1MIN).
+
         """
         if self._client is None:
             self._log.warning("Cannot unsubscribe: not connected")
@@ -396,7 +499,7 @@ class DYDXWebsocketClient:
 
     async def unsubscribe_markets(self) -> None:
         """
-        Unsubscribe from instrument updates.
+        Unsubscribe from market updates.
         """
         if self._client is None:
             self._log.warning("Cannot unsubscribe: not connected")
@@ -420,13 +523,27 @@ class DYDXWebsocketClient:
             return
 
         for subscription in self._subscriptions:
-            msg = {"type": "subscribe", "channel": subscription[0], "id": subscription[1]}
+            msg: dict[str, Any] = {
+                "type": "subscribe",
+                "channel": subscription[0],
+                "id": subscription[1],
+            }
+
+            if subscription[0] == "v4_orderbook":
+                msg["batched"] = True
+
             await self._send(msg)
 
-    def _send_subscribe_msg(self, msg: dict[str, Any]) -> None:
-        self._loop.create_task(self._send(msg))
-
     async def _send(self, msg: dict[str, Any]) -> None:
+        """
+        Send a message to the venue.
+
+        Parameters
+        ----------
+        msg : dict[str, Any]
+            Dictionary to serialize as JSON message and send
+
+        """
         if self._client is None:
             self._log.error(f"Cannot send message {msg}: not connected")
             return
