@@ -18,4 +18,5 @@ from typing import Final
 from nautilus_trader.model.identifiers import Venue
 
 
-OKX_VENUE: Final[Venue] = Venue("OKX")
+OKX: Final[str] = "OKX"
+OKX_VENUE: Final[Venue] = Venue(OKX)
