@@ -22,13 +22,13 @@ import pandas as pd
 from py_clob_client.client import ClobClient
 
 from nautilus_trader.adapters.polymarket.common.constants import POLYMARKET_VENUE
-from nautilus_trader.adapters.polymarket.common.enums import PolymarketOrderSide
+from nautilus_trader.adapters.polymarket.common.deltas import compute_effective_deltas
 from nautilus_trader.adapters.polymarket.common.symbol import get_polymarket_instrument_id
 from nautilus_trader.adapters.polymarket.common.symbol import get_polymarket_token_id
 from nautilus_trader.adapters.polymarket.config import PolymarketDataClientConfig
 from nautilus_trader.adapters.polymarket.providers import PolymarketInstrumentProvider
 from nautilus_trader.adapters.polymarket.schemas.book import PolymarketBookSnapshot
-from nautilus_trader.adapters.polymarket.schemas.book import PolymarketQuote
+from nautilus_trader.adapters.polymarket.schemas.book import PolymarketQuotes
 from nautilus_trader.adapters.polymarket.schemas.book import PolymarketTrade
 from nautilus_trader.adapters.polymarket.websocket.client import PolymarketWebSocketChannel
 from nautilus_trader.adapters.polymarket.websocket.client import PolymarketWebSocketClient
@@ -39,8 +39,10 @@ from nautilus_trader.common.component import MessageBus
 from nautilus_trader.common.enums import LogColor
 from nautilus_trader.core.uuid import UUID4
 from nautilus_trader.live.data_client import LiveMarketDataClient
+from nautilus_trader.model.book import OrderBook
 from nautilus_trader.model.data import BarType
 from nautilus_trader.model.data import DataType
+from nautilus_trader.model.data import OrderBookDeltas
 from nautilus_trader.model.data import QuoteTick
 from nautilus_trader.model.enums import BookType
 from nautilus_trader.model.identifiers import ClientId
@@ -99,7 +101,8 @@ class PolymarketDataClient(LiveMarketDataClient):
         # Configuration
         self._config = config
         self._log.info(f"{config.ws_connection_delay_secs=}", LogColor.BLUE)
-        self._log.info(f"{config.update_instrument_interval_mins=}", LogColor.BLUE)
+        self._log.info(f"{config.update_instruments_interval_mins=}", LogColor.BLUE)
+        self._log.info(f"{config.compute_effective_deltas=}", LogColor.BLUE)
 
         # HTTP API
         self._http_client = http_client
@@ -111,20 +114,25 @@ class PolymarketDataClient(LiveMarketDataClient):
         self._decoder_market_msg = msgspec.json.Decoder(MARKET_WS_MESSAGE)
 
         # Tasks
-        self._update_instrument_interval: int = config.update_instrument_interval_mins * 60
+        self._update_instruments_interval_mins: int | None = config.update_instruments_interval_mins
         self._update_instruments_task: asyncio.Task | None = None
         self._main_ws_connect_task: asyncio.Task | None = None
         self._main_ws_delay = True
 
         # Hot caches
         self._last_quotes: dict[InstrumentId, QuoteTick] = {}
+        self._local_books: dict[InstrumentId, OrderBook] = {}
 
     async def _connect(self) -> None:
         self._log.info("Initializing instruments...")
         await self._instrument_provider.initialize()
-
         self._send_all_instruments_to_data_engine()
-        self._update_instruments_task = self.create_task(self._update_instruments())
+
+        if self._update_instruments_interval_mins:
+            self._update_instruments_task = self.create_task(
+                self._update_instruments(self._update_instruments_interval_mins),
+            )
+
         self._main_ws_connect_task = self.create_task(self._connect_main_ws_after_delay())
 
     async def _disconnect(self) -> None:
@@ -183,15 +191,14 @@ class PolymarketDataClient(LiveMarketDataClient):
         for currency in self._instrument_provider.currencies().values():
             self._cache.add_currency(currency)
 
-    async def _update_instruments(self) -> None:
+    async def _update_instruments(self, interval_mins: int) -> None:
         try:
             while True:
                 self._log.debug(
-                    f"Scheduled task 'update_instruments' to run in "
-                    f"{self._update_instrument_interval}s",
+                    f"Scheduled task 'update_instruments' to run in {interval_mins} minutes",
                 )
-                await asyncio.sleep(self._update_instrument_interval)
-                await self._instrument_provider.initialize()
+                await asyncio.sleep(interval_mins * 60)
+                await self._instrument_provider.initialize(reload=True)
                 self._send_all_instruments_to_data_engine()
         except asyncio.CancelledError:
             self._log.debug("Canceled task 'update_instruments'")
@@ -229,6 +236,10 @@ class PolymarketDataClient(LiveMarketDataClient):
             )
             return
 
+        if self._config.compute_effective_deltas:
+            local_book = OrderBook(instrument_id, book_type=BookType.L2_MBP)
+            self._local_books[instrument_id] = local_book
+
         await self._subscribe_asset_book(instrument_id)
 
     async def _subscribe_quote_ticks(self, instrument_id: InstrumentId) -> None:
@@ -254,12 +265,12 @@ class PolymarketDataClient(LiveMarketDataClient):
 
     async def _unsubscribe_quote_ticks(self, instrument_id: InstrumentId) -> None:
         self._log.error(
-            f"Cannot unsubscribe from {instrument_id} quote ticks: unsubscribing not supported by Polymarket",
+            f"Cannot unsubscribe from {instrument_id} quotes: unsubscribing not supported by Polymarket",
         )
 
     async def _unsubscribe_trade_ticks(self, instrument_id: InstrumentId) -> None:
         self._log.error(
-            f"Cannot unsubscribe from {instrument_id} trade ticks: unsubscribing not supported by Polymarket",
+            f"Cannot unsubscribe from {instrument_id} trades: unsubscribing not supported by Polymarket",
         )
 
     async def _unsubscribe_bars(self, bar_type: BarType) -> None:
@@ -338,7 +349,7 @@ class PolymarketDataClient(LiveMarketDataClient):
         start: pd.Timestamp | None = None,
         end: pd.Timestamp | None = None,
     ) -> None:
-        self._log.error("Cannot request historical quote ticks: not published by Polymarket")
+        self._log.error("Cannot request historical quotes: not published by Polymarket")
 
     async def _request_trade_ticks(
         self,
@@ -348,7 +359,7 @@ class PolymarketDataClient(LiveMarketDataClient):
         start: pd.Timestamp | None = None,
         end: pd.Timestamp | None = None,
     ) -> None:
-        self._log.error("Cannot request historical trade ticks: not published by Polymarket")
+        self._log.error("Cannot request historical trades: not published by Polymarket")
 
     async def _request_bars(
         self,
@@ -365,21 +376,30 @@ class PolymarketDataClient(LiveMarketDataClient):
         # self._log.info(str(raw), LogColor.MAGENTA)
         try:
             ws_message = self._decoder_market_msg.decode(raw)
+            for msg in ws_message:
+                if isinstance(msg, list):
+                    if isinstance(msg, PolymarketBookSnapshot):
+                        instrument_id = get_polymarket_instrument_id(msg.market, msg.asset_id)
+                        instrument = self._cache.instrument(instrument_id)
+                        if instrument is None:
+                            self._log.error(f"Cannot find instrument for {instrument_id}")
+                            return
+                        self._handle_book_snapshot(instrument=instrument, ws_message=msg)
+                else:
+                    instrument_id = get_polymarket_instrument_id(msg.market, msg.asset_id)
+                    instrument = self._cache.instrument(instrument_id)
+                    if instrument is None:
+                        self._log.error(f"Cannot find instrument for {instrument_id}")
+                        return
 
-            instrument_id = get_polymarket_instrument_id(ws_message.market, ws_message.asset_id)
-            instrument = self._cache.instrument(instrument_id)
-            if instrument is None:
-                self._log.error(f"Cannot find instrument for {instrument_id}")
-                return
-
-            if isinstance(ws_message, PolymarketBookSnapshot):
-                self._handle_book_snapshot(instrument=instrument, ws_message=ws_message)
-            elif isinstance(ws_message, PolymarketQuote):
-                self._handle_quote(instrument=instrument, ws_message=ws_message)
-            elif isinstance(ws_message, PolymarketTrade):
-                self._handle_trade(instrument=instrument, ws_message=ws_message)
-            else:
-                self._log.error(f"Unknown websocket message topic: {ws_message}")
+                    if isinstance(msg, PolymarketBookSnapshot):
+                        self._handle_book_snapshot(instrument=instrument, ws_message=msg)
+                    elif isinstance(msg, PolymarketQuotes):
+                        self._handle_quote(instrument=instrument, ws_message=msg)
+                    elif isinstance(msg, PolymarketTrade):
+                        self._handle_trade(instrument=instrument, ws_message=msg)
+                    else:
+                        self._log.error(f"Unknown websocket message topic: {ws_message}")
         except Exception as e:
             self._log.error(f"Failed to parse websocket message: {raw.decode()} with error {e}")
 
@@ -389,26 +409,48 @@ class PolymarketDataClient(LiveMarketDataClient):
         ws_message: PolymarketBookSnapshot,
     ) -> None:
         now_ns = self._clock.timestamp_ns()
-        deltas = ws_message.parse_to_snapshot(
-            instrument=instrument,
-            ts_event=now_ns,
-            ts_init=now_ns,
-        )
-        self._handle_data(deltas)
+        deltas = ws_message.parse_to_snapshot(instrument=instrument, ts_init=now_ns)
+
+        self._handle_deltas(instrument, deltas)
 
         if instrument.id in self.subscribed_quote_ticks():
             quote = ws_message.parse_to_quote_tick(instrument=instrument, ts_init=now_ns)
             self._last_quotes[instrument.id] = quote
             self._handle_data(quote)
 
+    def _handle_deltas(self, instrument: BinaryOption, deltas: OrderBookDeltas) -> None:
+        if self._config.compute_effective_deltas:
+            # Compute effective deltas (reduce snapshot based on old and new book states),
+            # prioritizing a smaller data footprint over computational efficiency.
+            t0 = self._clock.timestamp_ns()
+            book_old = self._local_books.get(instrument.id)
+            book_new = OrderBook(instrument.id, book_type=BookType.L2_MBP)
+            book_new.apply_deltas(deltas)
+            self._local_books[instrument.id] = book_new
+            deltas = compute_effective_deltas(book_old, book_new, instrument)
+
+            interval_ms = (self._clock.timestamp_ns() - t0) / 1_000_000
+            self._log.debug(f"Computed effective deltas in {interval_ms:.3f}ms")
+            # self._log.warning(book_new.pprint())  # Uncomment for development
+
+        # Check if any effective deltas remain
+        if deltas:
+            self._handle_data(deltas)
+
     def _handle_quote(
         self,
         instrument: BinaryOption,
-        ws_message: PolymarketQuote,
+        ws_message: PolymarketQuotes,
     ) -> None:
         now_ns = self._clock.timestamp_ns()
-        delta = ws_message.parse_to_delta(instrument=instrument, ts_init=now_ns)
-        self._handle_data(delta)
+        deltas = ws_message.parse_to_deltas(instrument=instrument, ts_init=now_ns)
+
+        if self._config.compute_effective_deltas:
+            local_book = self._local_books.get(instrument.id)
+            if local_book:
+                local_book.apply_deltas(deltas)
+
+        self._handle_data(deltas)
 
         if instrument.id in self.subscribed_quote_ticks():
             last_quote = self._last_quotes.get(instrument.id)
@@ -416,29 +458,22 @@ class PolymarketDataClient(LiveMarketDataClient):
                 return
 
             # Check if top-of-book change
-            quote_price = instrument.make_price(float(ws_message.price))
-            if ws_message.side == PolymarketOrderSide.BUY:
-                if quote_price < last_quote.bid_price:
-                    return  # No top-of-book change
-            else:  # SELL
-                if quote_price > last_quote.ask_price:
-                    return  # No top-of-book change
-
-            quote = ws_message.parse_to_quote_tick(
+            quotes = ws_message.parse_to_quote_ticks(
                 instrument=instrument,
                 last_quote=last_quote,
                 ts_init=self._clock.timestamp_ns(),
             )
-            if (
-                quote.bid_price == last_quote.bid_price
-                and quote.ask_price == last_quote.ask_price
-                and quote.bid_size == last_quote.bid_size
-                and quote.ask_size == last_quote.ask_size
-            ):
-                return  # No top-of-book change
+            for quote in quotes:
+                if (
+                    quote.bid_price == last_quote.bid_price
+                    and quote.ask_price == last_quote.ask_price
+                    and quote.bid_size == last_quote.bid_size
+                    and quote.ask_size == last_quote.ask_size
+                ):
+                    continue  # No top-of-book change
 
-            self._last_quotes[instrument.id] = quote
-            self._handle_data(quote)
+                self._last_quotes[instrument.id] = quote
+                self._handle_data(quote)
 
     def _handle_trade(
         self,
