@@ -260,7 +260,7 @@ class DatabaseConfig(NautilusConfig, frozen=True):
 
     Notes
     -----
-    If `type` is 'redis' then requires Redis version 6.2.0 and above for correct operation.
+    If `type` is 'redis' then requires Redis version 6.2 or higher for correct operation (required for streams functionality).
 
     """
 
@@ -312,7 +312,7 @@ class MessageBusConfig(NautilusConfig, frozen=True):
         The lookback window in minutes for automatic stream trimming.
         The actual window may extend up to one minute beyond the specified value since streams are
         trimmed at most once every minute.
-        Note that this feature requires Redis version 6.2.0 or higher; otherwise it will result
+        Note that this feature requires Redis version 6.2 or higher; otherwise it will result
         in a command syntax error.
     use_trader_prefix : bool, default True
         If a 'trader-' prefix is used for stream names.
@@ -506,6 +506,9 @@ class LoggingConfig(NautilusConfig, frozen=True):
         If the logging system should be initialized via pyo3,
         this isn't recommended for backtesting as the performance is much lower
         but can be useful for seeing logs originating from Rust.
+    clear_log_file : bool, default False
+        If the log file name should be cleared before being used (e.g. for testing).
+        Only applies if `log_file_name` is not ``None``.
 
     """
 
@@ -519,6 +522,7 @@ class LoggingConfig(NautilusConfig, frozen=True):
     bypass_logging: bool = False
     print_config: bool = False
     use_pyo3: bool = False
+    clear_log_file: bool = False
 
 
 class ImportableFactoryConfig(NautilusConfig, frozen=True):
