@@ -22,6 +22,7 @@ import time
 from collections.abc import Callable
 from concurrent.futures import ThreadPoolExecutor
 from datetime import timedelta
+from pathlib import Path
 
 import msgspec
 
@@ -170,6 +171,17 @@ class NautilusKernel:
 
         if not is_logging_initialized():
             if not logging.bypass_logging:
+                if logging.clear_log_file and logging.log_directory and logging.log_file_name:
+                    file_path = Path(
+                        logging.log_directory,
+                        f"{logging.log_file_name}.{'log' if logging.log_file_format is None else 'json'}",
+                    )
+
+                    if file_path.exists():
+                        # Truncate log file to zero length and reset metadata
+                        file_path.touch()
+                        file_path.open("w").close()
+
                 if logging.use_pyo3:
                     set_logging_pyo3(True)
                     # Initialize tracing for async Rust
@@ -273,7 +285,7 @@ class NautilusKernel:
                 instance_id=self._instance_id,
                 serializer=MsgSpecSerializer(
                     encoding=msgspec.msgpack if encoding == "msgpack" else msgspec.json,
-                    timestamps_as_str=True,  # Hardcoded for now
+                    timestamps_as_str=True,  # Hard-coded for now
                     timestamps_as_iso8601=config.cache.timestamps_as_iso8601,
                 ),
                 config=config.cache,
@@ -293,7 +305,7 @@ class NautilusKernel:
             encoding = config.message_bus.encoding.lower()
             self._msgbus_serializer = MsgSpecSerializer(
                 encoding=msgspec.msgpack if encoding == "msgpack" else msgspec.json,
-                timestamps_as_str=True,  # Hardcoded for now
+                timestamps_as_str=True,  # Hard-coded for now
                 timestamps_as_iso8601=config.message_bus.timestamps_as_iso8601,
             )
         self._msgbus = MessageBus(
@@ -457,14 +469,16 @@ class NautilusKernel:
             self._setup_streaming(config=config.streaming)
 
         # Set up data catalog
-        self._catalog: ParquetDataCatalog | None = None
-        if config.catalog:
-            self._catalog = ParquetDataCatalog(
-                path=config.catalog.path,
-                fs_protocol=config.catalog.fs_protocol,
-                fs_storage_options=config.catalog.fs_storage_options,
-            )
-            self._data_engine.register_catalog(catalog=self._catalog)
+        self._catalogs: list[ParquetDataCatalog] = []
+        if config.catalogs:
+            for catalog_config in config.catalogs:
+                catalog = ParquetDataCatalog(
+                    path=catalog_config.path,
+                    fs_protocol=catalog_config.fs_protocol,
+                    fs_storage_options=catalog_config.fs_storage_options,
+                )
+                self._catalogs.append(catalog)
+                self._data_engine.register_catalog(catalog=catalog)
 
         # Create importable actors
         for actor_config in config.actors:
@@ -824,16 +838,16 @@ class NautilusKernel:
         return self._writer
 
     @property
-    def catalog(self) -> ParquetDataCatalog | None:
+    def catalogs(self) -> list[ParquetDataCatalog]:
         """
-        Return the kernels data catalog.
+        Return the kernel's list of data catalogs.
 
         Returns
         -------
-        ParquetDataCatalog or ``None``
+        list[ParquetDataCatalog]
 
         """
-        return self._catalog
+        return self._catalogs
 
     def get_log_guard(self) -> nautilus_pyo3.LogGuard | LogGuard | None:
         """
