@@ -17,6 +17,7 @@ import datetime as dt
 import pathlib
 import random
 from decimal import Decimal
+from pathlib import Path
 from typing import Any
 
 import fsspec
@@ -25,6 +26,8 @@ import pandas as pd
 import pytz
 from fsspec.implementations.local import LocalFileSystem
 
+from nautilus_trader import PACKAGE_ROOT
+from nautilus_trader.core import nautilus_pyo3
 from nautilus_trader.core.correctness import PyCondition
 from nautilus_trader.core.datetime import dt_to_unix_nanos
 from nautilus_trader.core.datetime import secs_to_nanos
@@ -71,6 +74,8 @@ class TestInstrumentProvider:
     Provides instrument template methods for backtesting.
     """
 
+    __test__ = False  # Prevents pytest from collecting this as a test class
+
     @staticmethod
     def adabtc_binance() -> CurrencyPair:
         """
@@ -670,7 +675,7 @@ class TestInstrumentProvider:
             event_open_date=pd.Timestamp("2022-02-07 23:30:00+00:00"),
             event_type_id=6423,
             event_type_name="American Football",
-            market_id="1.123456789",
+            market_id="1-123456789",
             market_name="AFC Conference Winner",
             market_start_time=pd.Timestamp("2022-02-07 23:30:00+00:00"),
             market_type="SPECIAL",
@@ -685,7 +690,7 @@ class TestInstrumentProvider:
         )
 
     @staticmethod
-    def binary_option() -> CurrencyPair:
+    def binary_option() -> BinaryOption:
         raw_symbol = Symbol(
             "0x12a0cb60174abc437bf1178367c72d11f069e1a3add20b148fb0ab4279b772b2-92544998123698303655208967887569360731013655782348975589292031774495159624905",
         )
@@ -783,6 +788,8 @@ class TestDataProvider:
 
     """
 
+    __test__ = False  # Prevents pytest from collecting this as a test class
+
     def __init__(self, branch: str = "develop") -> None:
         self.fs: fsspec.AbstractFileSystem | None = None
         self.root: str | None = None
@@ -853,6 +860,9 @@ class TestDataProvider:
 
 
 class TestDataGenerator:
+
+    __test__ = False  # Prevents pytest from collecting this as a test class
+
     @staticmethod
     def simulate_value_diffs(
         count: int,
@@ -947,3 +957,53 @@ class TestDataGenerator:
             )
             for idx, row in df.iterrows()
         ]
+
+
+def get_test_data_large_path() -> Path:
+    return (PACKAGE_ROOT / "tests" / "test_data" / "large").resolve()
+
+
+def get_test_data_large_checksums_filepath() -> Path:
+    return (get_test_data_large_path() / "checksums.json").resolve()
+
+
+def ensure_test_data_exists(filename: str, url: str) -> Path:
+    filepath = (get_test_data_large_path() / filename).resolve()
+    checksums_filepath = get_test_data_large_checksums_filepath()
+    nautilus_pyo3.ensure_file_exists_or_download_http(str(filepath), url, str(checksums_filepath))
+    return filepath
+
+
+def ensure_data_exists_tardis_deribit_book_l2() -> Path:
+    filename = "tardis_deribit_incremental_book_L2_2020-04-01_BTC-PERPETUAL.csv.gz"
+    base_url = "https://datasets.tardis.dev"
+    url = f"{base_url}/v1/deribit/incremental_book_L2/2020/04/01/BTC-PERPETUAL.csv.gz"
+    return ensure_test_data_exists(filename, url)
+
+
+def ensure_data_exists_tardis_binance_snapshot5() -> Path:
+    filename = "tardis_binance-futures_book_snapshot_5_2020-09-01_BTCUSDT.csv.gz"
+    base_url = "https://datasets.tardis.dev"
+    url = f"{base_url}/v1/binance-futures/book_snapshot_5/2020/09/01/BTCUSDT.csv.gz"
+    return ensure_test_data_exists(filename, url)
+
+
+def ensure_data_exists_tardis_binance_snapshot25() -> Path:
+    filename = "tardis_binance-futures_book_snapshot_25_2020-09-01_BTCUSDT.csv.gz"
+    base_url = "https://datasets.tardis.dev"
+    url = f"{base_url}/v1/binance-futures/book_snapshot_25/2020/09/01/BTCUSDT.csv.gz"
+    return ensure_test_data_exists(filename, url)
+
+
+def ensure_data_exists_tardis_huobi_quotes() -> Path:
+    filename = "tardis_huobi-dm-swap_quotes_2020-05-01_BTC-USD.csv.gz"
+    base_url = "https://datasets.tardis.dev"
+    url = f"{base_url}/v1/huobi-dm-swap/quotes/2020/05/01/BTC-USD.csv.gz"
+    return ensure_test_data_exists(filename, url)
+
+
+def ensure_data_exists_tardis_bitmex_trades() -> Path:
+    filename = "tardis_bitmex_trades_2020-03-01_XBTUSD.csv.gz"
+    base_url = "https://datasets.tardis.dev"
+    url = f"{base_url}/v1/bitmex/trades/2020/03/01/XBTUSD.csv.gz"
+    return ensure_test_data_exists(filename, url)
